==> kvision-redux-kotlin-5.6.1.jar: kvision-kvision-redux-kotlin-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'Redux-Kotlin-redux-kotlin-jsLegacy', 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy', 'kvision-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('Redux-Kotlin-redux-kotlin-jsLegacy'), require('Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'), require('kvision-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }if (typeof this['Redux-Kotlin-redux-kotlin-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'Redux-Kotlin-redux-kotlin-jsLegacy' was not found. Please, check whether 'Redux-Kotlin-redux-kotlin-jsLegacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }if (typeof this['Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy' was not found. Please, check whether 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }root['kvision-kvision-redux-kotlin-js-legacy'] = factory(typeof this['kvision-kvision-redux-kotlin-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-redux-kotlin-js-legacy'], kotlin, this['Redux-Kotlin-redux-kotlin-jsLegacy'], this['Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'], this['kvision-js-legacy']);
  }
}(this, function (_, Kotlin, $module$Redux_Kotlin_redux_kotlin_jsLegacy, $module$Redux_Kotlin_thunk_redux_kotlin_thunk_jsLegacy, $module$kvision_js_legacy) {
  'use strict';
  var Kind_INTERFACE = Kotlin.Kind.INTERFACE;
  var throwCCE = Kotlin.throwCCE;
  var Unit = Kotlin.kotlin.Unit;
  var ActionTypes = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.ActionTypes;
  var equals = Kotlin.equals;
  var createThunkMiddleware = $module$Redux_Kotlin_thunk_redux_kotlin_thunk_jsLegacy.org.reduxkotlin.createThunkMiddleware_tpy1pm$;
  var applyMiddleware = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.applyMiddleware_o612nn$;
  var createStore = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.createStore_4jmha0$;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var ObservableState = $module$kvision_js_legacy.io.kvision.state.ObservableState;
  function RAction() {
  }
  RAction.$metadata$ = {
    kind: Kind_INTERFACE,
    simpleName: 'RAction',
    interfaces: []
  };
  function createReduxStore(reducer, initialState, middlewares) {
    return new ReduxStore(reducer, initialState, middlewares.slice());
  }
  function ReduxStore(reducer, initialState, middlewares) {
    this.store_0 = createStore(ReduxStore$store$lambda(reducer), initialState, applyMiddleware([createThunkMiddleware()].concat(middlewares)));
  }
  ReduxStore.prototype.getState = function () {
    return this.store_0.getState();
  };
  ReduxStore.prototype.dispatch_dtrwrh$ = function (action) {
    this.store_0.dispatch(action);
  };
  function ReduxStore$dispatch$lambda(closure$actionCreator) {
    return function (dispatch, getState, f) {
      var tmp$;
      closure$actionCreator(typeof (tmp$ = dispatch) === 'function' ? tmp$ : throwCCE(), getState);
      return Unit;
    };
  }
  ReduxStore.prototype.dispatch_8lralg$ = function (actionCreator) {
    var thunk = ReduxStore$dispatch$lambda(actionCreator);
    this.store_0.dispatch(thunk);
  };
  function ReduxStore$subscribe$lambda(closure$observer, this$ReduxStore) {
    return function () {
      closure$observer(this$ReduxStore.getState());
      return Unit;
    };
  }
  ReduxStore.prototype.subscribe_qlkmfe$ = function (observer) {
    observer(this.getState());
    return this.store_0.subscribe(ReduxStore$subscribe$lambda(observer, this));
  };
  function ReduxStore$store$lambda(closure$reducer) {
    return function (s, a) {
      var tmp$;
      if (equals(a, ActionTypes.INIT) || equals(a, ActionTypes.REPLACE)) {
        return s;
      } else {
        return closure$reducer(s, Kotlin.isType(tmp$ = a, RAction) ? tmp$ : throwCCE());
      }
    };
  }
  ReduxStore.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ReduxStore',
    interfaces: [ObservableState]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$redux = package$kvision.redux || (package$kvision.redux = {});
  package$redux.RAction = RAction;
  package$redux.createReduxStore_vfspf5$ = createReduxStore;
  package$redux.ReduxStore = ReduxStore;
  Kotlin.defineModule('kvision-kvision-redux-kotlin-js-legacy', _);
  return _;
}));

==> kvision-redux-kotlin-5.14.0.jar: kvision-kvision-redux-kotlin-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'Redux-Kotlin-redux-kotlin-jsLegacy', 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy', 'kvision-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('Redux-Kotlin-redux-kotlin-jsLegacy'), require('Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'), require('kvision-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }
    if (typeof this['Redux-Kotlin-redux-kotlin-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'Redux-Kotlin-redux-kotlin-jsLegacy' was not found. Please, check whether 'Redux-Kotlin-redux-kotlin-jsLegacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }
    if (typeof this['Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy' was not found. Please, check whether 'Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }
    if (typeof this['kvision-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-redux-kotlin-js-legacy'. Its dependency 'kvision-js-legacy' was not found. Please, check whether 'kvision-js-legacy' is loaded prior to 'kvision-kvision-redux-kotlin-js-legacy'.");
    }
    root['kvision-kvision-redux-kotlin-js-legacy'] = factory(typeof this['kvision-kvision-redux-kotlin-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-redux-kotlin-js-legacy'], kotlin, this['Redux-Kotlin-redux-kotlin-jsLegacy'], this['Redux-Kotlin-thunk-redux-kotlin-thunk-jsLegacy'], this['kvision-js-legacy']);
  }
}(this, function (_, Kotlin, $module$Redux_Kotlin_redux_kotlin_jsLegacy, $module$Redux_Kotlin_thunk_redux_kotlin_thunk_jsLegacy, $module$kvision_js_legacy) {
  'use strict';
  var Kind_INTERFACE = Kotlin.Kind.INTERFACE;
  var throwCCE = Kotlin.throwCCE;
  var Unit = Kotlin.kotlin.Unit;
  var ActionTypes = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.ActionTypes;
  var equals = Kotlin.equals;
  var createThunkMiddleware = $module$Redux_Kotlin_thunk_redux_kotlin_thunk_jsLegacy.org.reduxkotlin.createThunkMiddleware_tpy1pm$;
  var applyMiddleware = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.applyMiddleware_o612nn$;
  var createStore = $module$Redux_Kotlin_redux_kotlin_jsLegacy.org.reduxkotlin.createStore_4jmha0$;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var ObservableState = $module$kvision_js_legacy.io.kvision.state.ObservableState;
  function RAction() {
  }
  RAction.$metadata$ = {
    kind: Kind_INTERFACE,
    simpleName: 'RAction',
    interfaces: []
  };
  function createReduxStore(reducer, initialState, middlewares) {
    return new ReduxStore(reducer, initialState, middlewares.slice());
  }
  function ReduxStore(reducer, initialState, middlewares) {
    this.store_0 = createStore(ReduxStore$store$lambda(reducer), initialState, applyMiddleware([createThunkMiddleware()].concat(middlewares)));
  }
  ReduxStore.prototype.getState = function () {
    return this.store_0.getState();
  };
  ReduxStore.prototype.dispatch_dtrwrh$ = function (action) {
    this.store_0.dispatch(action);
  };
  function ReduxStore$dispatch$lambda(closure$actionCreator) {
    return function (dispatch, getState, f) {
      var tmp$;
      closure$actionCreator(typeof (tmp$ = dispatch) === 'function' ? tmp$ : throwCCE(), getState);
      return Unit;
    };
  }
  ReduxStore.prototype.dispatch_8lralg$ = function (actionCreator) {
    var thunk = ReduxStore$dispatch$lambda(actionCreator);
    this.store_0.dispatch(thunk);
  };
  function ReduxStore$subscribe$lambda(closure$observer, this$ReduxStore) {
    return function () {
      closure$observer(this$ReduxStore.getState());
      return Unit;
    };
  }
  ReduxStore.prototype.subscribe_qlkmfe$ = function (observer) {
    observer(this.getState());
    return this.store_0.subscribe(ReduxStore$subscribe$lambda(observer, this));
  };
  function ReduxStore$store$lambda(closure$reducer) {
    return function (s, a) {
      var tmp$;
      if (equals(a, ActionTypes.INIT) || equals(a, ActionTypes.REPLACE)) {
        return s;
      } else {
        return closure$reducer(s, Kotlin.isType(tmp$ = a, RAction) ? tmp$ : throwCCE());
      }
    };
  }
  ReduxStore.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ReduxStore',
    interfaces: [ObservableState]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$redux = package$kvision.redux || (package$kvision.redux = {});
  package$redux.RAction = RAction;
  package$redux.createReduxStore_vfspf5$ = createReduxStore;
  package$redux.ReduxStore = ReduxStore;
  Kotlin.defineModule('kvision-kvision-redux-kotlin-js-legacy', _);
  return _;
}));
